ChangeLog
=========

0.1.5
---------

*Date: 2014-06-11*

-  bug fix:pip install bug in windows platform

0.1.5dev-20140611
---------

*Date: 2014-06-11*

-  bug fix:pypi data_files

0.1.4
---------

*Date: 2014-06-11*

-  the latest release

0.1.4dev-20140611
---------

*Date: 2014-06-11*

-  modify the README.md. Now it is consistent with rst format to display on pypi

0.1.4dev-20140610
---------

*Date: 2014-06-10*

-  add support for installing from pip

0.1.4dev3
---------

*Date: 2014-06-10*

-  bug fix

   -  fix the binary write problem in windows platform

0.1.4dev2
---------

*Date: 2014-06-10*

-  add setuptools install support

0.1.4dev1
---------

*Date: 2014-06-09*

-  bug fix

   -  rangedownloader:http range-headers may not be supported

0.1.3
-----

*Date: 2014-06-07*

-  do some refactory

   -  add conf dictionary

0.1.2
-----

*Date: 2014-06-06*

-  add plugin

   -  pixiv

0.1.1
-----

*Date: 2014-06-05*

-  add plugin

   -  gamersky

0.0.1
-----

*Date: 2014-06-05*

-  init the project


